@@ -76,13 +76,15 @@ int rad_accounting_sql(AUTH_REQ *authreq, int authtype, char *f, SQLSOCK *socket
 	time_t		nowtime;
 	struct tm	*tim;
         char		datebuf[20];
+	char		*valbuf;
+#if 0 /* FIXME: Database backup code */
 	int		*sqlpid;
 	int		sqlstatus;
 	FILE		*backupfile;
 	struct stat	backup;
-	char		*valbuf;
-	SQLREC sqlrecord = {"", "", "", "", 0, "", "", 0, "", 0, "", "", 0, 0, "", "", "", "", "", "", 0};
 	SQLREC backuprecord = {"", "", "",  "", 0, "", "", 0, "", 0, "", "", 0, 0, "", "", "", "", "", "", 0};
+#endif
+	SQLREC sqlrecord = {"", "", "", "", 0, "", "", 0, "", 0, "", "", 0, 0, "", "", "", "", "", "", 0};
 	VALUE_PAIR	*pair;
 	int		ret = 0;
 
@@ -198,6 +200,8 @@ int rad_accounting_sql(AUTH_REQ *authreq, int authtype, char *f, SQLSOCK *socket
         strncpy(sqlrecord.AcctTimeStamp, datebuf, 20);
        
 
+#if 0 /* FIXME: Make this actually work */
+
 	/* If backup file exists we know the database was down */
 	if(stat(MYSQLBACKUP, &backup) == 0) {
 		if(backup.st_size > 0) {
@@ -220,7 +224,7 @@ int rad_accounting_sql(AUTH_REQ *authreq, int authtype, char *f, SQLSOCK *socket
 #if defined(F_LOCK) && !defined( BSD)
 				(void)lockf((int)backupfile, (int)F_LOCK, (off_t)SQL_LOCK_LEN);
 #else
-				(void)flock(backupfile, SQL_LOCK_EX);
+				(void)flock(backupfile, LOCK_EX);
 #endif  
 
 				log(L_INFO, "Acct:  Clearing out sql backup file - %s", MYSQLBACKUP);
@@ -240,6 +244,8 @@ int rad_accounting_sql(AUTH_REQ *authreq, int authtype, char *f, SQLSOCK *socket
 			}
 		}
 	}
+#endif
+
 	ret = sql_save_acct(socket, &sqlrecord);
 
 	return ret;
@@ -294,13 +300,13 @@ int rad_accounting_file(AUTH_REQ *authreq, int authtype, char *f)
 	/*
          *      Create a directory for this nas.
          */
-        sprintf(buffer, "%.250s/%.250s", radacct_dir, nasname);
+        sprintf(buffer, "%.100s%.150s/%.250s", dir_prefix, radacct_dir, nasname);
         (void) mkdir(buffer, 0755);
 
         /*
          *      Write Detail file.
          */
-        sprintf(buffer, "%.200s/%.200s/%.100s", radacct_dir, nasname, f ? f : "detail");
+        sprintf(buffer, "%.100s%.100s/%.200s/%.100s", dir_prefix, radacct_dir, nasname, f ? f : "detail");
         if((outfd = fopen(buffer, "a")) == (FILE *)NULL) {
 	   log(L_ERR, "Acct: Couldn't open file %s", buffer);
 	   return -1;
