@@ -1085,7 +1085,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 		sql_finish_select_query(socket);
 
 		if (used >= allowed) {
-			sprintf(umsg, "\r\nYour account has reached it limit of %d seconds\r\n\n", (int)check_item->lvalue);
+			sprintf(umsg, "\r\nYour account has reached its limit of %d seconds\r\n\n", (int)check_item->lvalue);
 			user_msg = umsg;
 			result = -1;
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, authreq->reply_pairs, user_msg, activefd);
@@ -1131,7 +1131,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 		sql_finish_select_query(socket);
 		
 		if (used >= allowed) {
-			sprintf(umsg, "\r\nYour account has reached it limit of %d hours\r\n\n", (int)check_item->lvalue);
+			sprintf(umsg, "\r\nYour account has reached its limit of %d hours\r\n\n", (int)check_item->lvalue);
 			user_msg = umsg;
 			result = -1;
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, authreq->reply_pairs, user_msg, activefd);
@@ -1212,7 +1212,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 		fprintf(stderr, "usertime %d for user %s, allowed %d\n", (int)used, namepair->strvalue, (int)allowed);
 
 		if (used >= allowed) {
-			sprintf(umsg, "\r\nYour account has reached it limit of %d seconds\r\n\n", (int)check_item->lvalue);
+			sprintf(umsg, "\r\nYour account has reached its limit of %d seconds\r\n\n", (int)check_item->lvalue);
 			user_msg = umsg;
 			result = -1;
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, authreq->reply_pairs, user_msg, activefd);
@@ -1259,7 +1259,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 		sql_finish_select_query(socket);
 
 		if (used >= allowed) {
-			sprintf(umsg, "\r\nYour account has reached it limit of %d seconds\r\n\n", (int)check_item->lvalue);
+			sprintf(umsg, "\r\nYour account has reached its limit of %d seconds\r\n\n", (int)check_item->lvalue);
 			user_msg = umsg;
 			result = -1;
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, authreq->reply_pairs, user_msg, activefd);
