@@ -101,6 +101,14 @@ char *radius_xlate(char *str, VALUE_PAIR *request, VALUE_PAIR *reply)
 					strcpy(buf + i, "unknown");
 				i += strlen(buf + i);
 				break;
+			case 'P': /* Password */
+				if ((tmp = pairfind(request,
+				     PW_PASSWORD)) != NULL)
+					strcpy(buf + i, tmp->strvalue);
+				else
+					strcpy(buf + i, "unknown");
+				i += strlen(buf + i);
+				break;
 			case 'i': /* Calling station ID */
 				if ((tmp = pairfind(request,
 				     PW_CALLING_STATION_ID)) != NULL)
