@@ -1774,8 +1774,8 @@ int read_config_files(SQLSOCK *socket) {
 	pairlist_free(&huntgroups);
 	pairlist_free(&hints);
 
-	DEBUG2("Reading huntgroups file %s/%s", radius_dir, RADIUS_HUNTGROUPS);
-	sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_HUNTGROUPS);
+	DEBUG2("Reading huntgroups file %s%s/%s", dir_prefix, radius_dir, RADIUS_HUNTGROUPS);
+	sprintf(buffer, "%.100s%.100s/%.50s", dir_prefix, radius_dir, RADIUS_HUNTGROUPS);
 	huntgroups = file_read(buffer, 0);
 
 	hints = sql_read_hints(socket);
