@@ -76,7 +76,7 @@ int sql_init(int reload) {
 		sql->config->max_sql_oldsocks = MAX_SQL_SOCKS;
 	sql->config->max_sql_socks = MAX_SQL_SOCKS;
 
-        sprintf(sqlfile, "%s/%s", radius_dir, MYSQLCONFIG);
+        sprintf(sqlfile, "%s%s/%s", dir_prefix, radius_dir, MYSQLCONFIG);
         if((sqlfd = fopen(sqlfile, "r")) == (FILE *)NULL) {
                 log(L_ERR,"could not read MySQL configuration file %s",sqlfile);
                 return(-1);
@@ -148,6 +148,7 @@ int sql_init(int reload) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
                          strcpy(sql->config->sql_db,namestr);
+                         strcpy(sql->config->sql_acct_db,namestr);
                        }
                }
                 if(strncasecmp(buffer, "radius_acct_db", 14) == 0) {
@@ -442,7 +443,7 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
 #if defined(F_LOCK) && !defined(BSD)
 		(void)lockf((int)mysqlfile, (int)F_LOCK, (off_t)SQL_LOCK_LEN);
 #else
-		(void)flock(mysqlfile, SQL_LOCK_EX);
+		(void)flock(mysqlfile, LOCK_EX);
 #endif
 	}
 
